@@ -92,6 +92,8 @@ class Monitor(Thread):
             logger.debug(f"Auto val not found for {', '.join(auto_keys)}")
             logger.error(f"Autoload not supported for {cls.name}.")
             raise AutoloadError
+        except FileNotFoundError as e:
+            raise AutoloadError(src=e.filename)
         while auto_keys:
             param = auto_keys.pop()
             try:
@@ -103,7 +105,6 @@ class Monitor(Thread):
                 monitor_cfg[param] = param_loader()
                 logger.debug(f"Autoloaded {cls.name} {param} = {monitor_cfg[param]}")
             except FileNotFoundError as e:
-                logger.error(f"File not found: {e.filename}")
                 raise AutoloadError(src=e.filename)
         return monitor_cfg
 
@@ -126,16 +127,17 @@ class Monitor(Thread):
         self.preview_timer: ResumableTimer = None
         self.fast_pause_timer: ResumableTimer = None
 
-    def parse_status(self):
+    @staticmethod
+    def parse_status(status):
         if (
-            'filepath' not in self.status and 'media_info' not in self.status
-        ) or not self.status.get('duration'):
+            'filepath' not in status and 'media_info' not in status
+        ) or not status.get('duration'):
             return {}
 
-        if 'filepath' in self.status:
-            media_info = get_media_info(self.status['filepath'])
+        if 'filepath' in status:
+            media_info = get_media_info(status['filepath'])
         else:
-            media_info = self.status['media_info']
+            media_info = status['media_info']
 
         if media_info is None:
             return {}
@@ -144,18 +146,20 @@ class Monitor(Thread):
         if isinstance(ep, list):
             media_info = media_info.copy()
             num_eps = len(media_info['episode'])
-            self.status['duration'] = self.status['duration'] // num_eps
-            ep_num = int(self.status['position'] // self.status['duration'])
+            status['duration'] //= num_eps
+            ep_num, status['position'] = divmod(status['position'], status['duration'])
+            ep_num = int(ep_num)
+            # handle case when pos >= duration, causing ep_num == num_eps
+            if ep_num == num_eps:
+                ep_num -= 1
+                status['position'] = status['duration']
             media_info['episode'] = media_info['episode'][ep_num]
-            self.status['position'] %= self.status['duration']
         elif isinstance(ep, str):
             media_info['episode'] = int(ep)
 
-        progress = min(
-            round(self.status['position'] * 100 / self.status['duration'], 2), 100
-        )
+        progress = min(round(status['position'] * 100 / status['duration'], 2), 100)
         return {
-            'state': self.status['state'],
+            'state': status['state'],
             'progress': progress,
             'media_info': media_info,
             'updated_at': time.time(),
@@ -255,7 +259,7 @@ class Monitor(Thread):
         Possible race conditions:
         1) start_preview, after __preview_duration__ secs, stop_preview
            start_preview starts preview_timer for " secs, with cleanup=exit_preview.
-           the stop_preview also triggers exit_preview, both are run parallely.
+           the stop_preview also triggers exit_preview, both are run parallelly.
         """
         for action in self.decide_action(prev, current):
             logger.debug(f"action={action}")
@@ -301,7 +305,7 @@ class Monitor(Thread):
                 logger.warning(f"Invalid action {action}")
 
     def handle_status_update(self):
-        current_state = self.parse_status()
+        current_state = self.parse_status(self.status)
         with self.lock:
             self.scrobble_if_state_changed(self.prev_state, current_state)
         self.prev_state = current_state
